<?php

namespace Litecms\GiftCardSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\GiftCardSetting\Models\GiftCardSetting;

class GiftCardSettingPolicy
{

    /**
     * Determine if the given user can view the gift_card_setting.
     *
     * @param UserPolicy $user
     * @param GiftCardSetting $gift_card_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, GiftCardSetting $gift_card_setting)
    {
        if ($user->canDo('gift_card_setting.gift_card_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $gift_card_setting->user_id == user_id() && $gift_card_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a gift_card_setting.
     *
     * @param UserPolicy $user
     * @param GiftCardSetting $gift_card_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('gift_card_setting.gift_card_setting.create');
    }

    /**
     * Determine if the given user can update the given gift_card_setting.
     *
     * @param UserPolicy $user
     * @param GiftCardSetting $gift_card_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, GiftCardSetting $gift_card_setting)
    {
        if ($user->canDo('gift_card_setting.gift_card_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $gift_card_setting->user_id == user_id() && $gift_card_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given gift_card_setting.
     *
     * @param UserPolicy $user
     * @param GiftCardSetting $gift_card_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, GiftCardSetting $gift_card_setting)
    {
        return $gift_card_setting->user_id == user_id() && $gift_card_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given gift_card_setting.
     *
     * @param UserPolicy $user
     * @param GiftCardSetting $gift_card_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, GiftCardSetting $gift_card_setting)
    {
        if ($user->canDo('gift_card_setting.gift_card_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given gift_card_setting.
     *
     * @param UserPolicy $user
     * @param GiftCardSetting $gift_card_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, GiftCardSetting $gift_card_setting)
    {
        if ($user->canDo('gift_card_setting.gift_card_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
